#!/usr/bin/env python


from DarcReport import DarcReport


class HtmlReport(DarcReport):

	def gen_report(self):
		r = self.get_head()
		r += self.get_summary()
		r += self.get_host_lists()
		r += self.get_full_host_reports()
		r += self.get_problem_logs()
		return r


	def get_head(self):
		head = '''
<html>
<head>
<title>
DARC AIDE Report
</title>

<style type="text/css">
</style>

</head>
<body>

'''

		return head


	def get_summary(self):

		tmpl = '''
<h1>DARC AIDE Report </h1>

<h2>Summary</h2>
<table>
<tr>
  <td> %(numhosts)s </td>
  <td> hosts listed for monitoring </td>
</tr>

<tr>
  <td> %(numinit)s </td>
  <td> hosts were initialized </td>
</tr>

<tr>
  <td> %(numfail)s </td>
  <td> hosts failed with file modifications </td>
</tr>

<tr>
  <td> %(numpass)s </td>
  <td> hosts passed without file modifications </td>
</tr>

<tr>
  <td> %(numprob)s </td>
  <td> hosts were unable to be checked </td>
</tr>

</table>

<hr>

''' % { 'numhosts': self.total_c, 
        'numinit': self.init_c, 
        'numfail': self.fail_c, 
        'numpass': self.pass_c, 
		'numprob': self.prob_c }

		return tmpl



	def get_host_lists(self):

		# failed host list section
		if len(self.fail_list) == 0:
			fail_text = ''
		else:
			fail_text = '''
<h2 id="failed_host_list">
Failed Host List
</h2>
'''
		
		for x in self.fail_list:
			fail_text +=  '<a href="#fail_%s">%s</a> <br>\n' % (x.hostname,x.hostname)

		fail_text += '<br><br>'

		# problem checking section
		if len(self.prob_list) == 0:
			prob_text = ''
		else:
			prob_text = '''

<h2 id="unchecked_host_list">
Unchecked Host List
</h2>
'''

		for x in self.prob_list:
			prob_text +=  '<a href="#prob_%s">%s</a> <br>\n' % (x.hostname,x.hostname)

		return fail_text + prob_text
	


	def get_full_host_reports(self):
		
		if len(self.fail_list) == 0:
			return ''
		else:
			text = '''

<hr>
<h2>
Detailed AIDE Reports
</h2>

'''
		for x in self.fail_list:
			text += '''
<h4 id="fail_%s">%s (failed):</h4><br>
<pre>
''' % (x.hostname,x.hostname)

			rep_fh = open(x.report,'r')
			ln = rep_fh.readline()
			while ln:
				text += '      ' + ln
				ln = rep_fh.readline()
			rep_fh.close()

			text += '</pre><hr>'

		return text


	def get_problem_logs(self):

		if len(self.prob_list) == 0:
			return ''
		else:
			text = '''

<hr>
<h2>
Unchecked Host Problem Details
</h2>

'''
		for x in self.prob_list:
			text += '<hr>\n'
			text += '<h4 id="prob_%s">%s (unchecked):\n' % (x.hostname,x.hostname)
			for ln in x.status_detail:
				text +=  str(ln) + '\n'
			text += '\n\n'

		return text

