#!/usr/bin/env python
#
# $Id: config.py 45 1996-04-23 20:15:13Z darc $
#
# sample darc config file
#
# The contents of this file get imported as a module named "config"
# within darc.py at runtime.
#
# 
# Jacob Martinson <martinson.jacob at gmail.com>
#
# This software is licensed under the Gnu Public License
# For more info see: 
#         http://www.gnu.org/licenses/gpl.html

from DarcHost import host
import syslog

# --------------------------------------------------------------------------
# GLOBAL CONFIG SECTION
# --------------------------------------------------------------------------

# This is the top level location for all the files darc creates in the 
# process of monitoring hosts with aide.  This directory can grow large
# if you monitor a large number of hosts with many files on their 
# filesystems.
basedir   = '/home/darc/base'


dbdir     = basedir + '/baseline_db'
dbarchdir = basedir + '/archive_db'
tmpdir    = basedir + '/tmp'
bindir    = basedir + '/bin'
reportdir = basedir + '/reports'
confdir   = basedir + '/configs'
lockfile  = basedir + '/lock'

remotedir = '/home/darc'

# Remote filename - what the aide binary will be named on the remote end
# when it runs.  Best not to use 'aide' because it could tip off an
# intruder the system is being monitored.
#
# If you specify 'random' as the name, we'll generate a psuedo-random
# 8-character string each time.
aide_filename = 'random'

# ssh tcp connection timeout
connect_timeout = 5

# how long sftp has to transfer aide binary before we kill it and
# call it quits
sftp_xfer_timeout = 10

# Time aide is allowed to run before we consider it dead
aide_timeout    = 1800

# Default username to connect to remote host as
default_user = 'darc'

# Default system architecture 
default_arch = 'linux'

# Default ssh private key file to authenticate with
default_key = '/home/darc/.ssh/id_dsa'

# The period of time in seconds we wait between launching parallel
# sftp and ssh processes.  If you are monitoring a large number of hosts
# this can prevent the cpu usage from spiking from a hundred key 
# exchanges happening at once.
popen_interval = 1

# Local aide path, used to run database comparisons.  Do not set this to
# a shell script wrapper distributed with aide - this needs to be the
# actual aide binary.
local_aide_binary = bindir + '/aide-0.11.linux'

# syslog options - for info on available constants, see
# http://docs.python.org/lib/module-syslog.html
#
# syslog logging is only enabled if the -y option is given at runtime
#
syslog_priority = syslog.LOG_NOTICE
syslog_facility = syslog.LOG_AUTH

# Who to send email reports to if the -e option is given
# This must be a list, even if it only contains one element.
rcpt_list = ['martinson.jacob@gmail.com']

# Who the mail should claim to come from
mail_from = 'noreply@asdf.com'

# 'binmap' tells us which binary to use for each architecture type. This 
# is added to bindir to generate the full path to the binary.
#
# The key is meant to be a binary architecture type, and the value is
# meant to be the filename of the binary to use, which is appended to 
# the 'bindir' variable.
#
# binmap = {
# 	'linux':   'aide-0.10.linux',
# 	'solaris': 'aide-0.10.sol',
# 	'aix':     'aide-0.9.aix',
# }
#

binmap = {
	'linux':   'aide-0.11.linux',
	'solaris': 'aide-0.11.solaris',
	'aix':     'aide-0.9.aix',
}


# --------------------------------------------------------------------------
# HOST DEFINITIONS
# --------------------------------------------------------------------------
#
# 'hostname' is used both to identify the target system in reports and for
# name resolution in ssh.
#
# 'arch' defines the system architecture, which is used in conjunction 
# with 'binmap' to determine which aide binary to deliver to the target.
#
# 'aconf' defines which aide aconfuration file to send to the target.
# this string is appended to 'confdir' to generate the full path.
#
# Example:
#
# h1 = host(hostname='localhost',arch='linux',aconf='linux')
#

thai = host(hostname='thai',aconf='linux.conf')

subversion = host(hostname='subversion',aconf='linux.conf')
web_srv1 = host(hostname='web_srv1',aconf='solaris.conf',arch='solaris',remotedir='/export/home/darc')
web_srv2 = host(hostname='web_srv2',aconf='solaris.conf',arch='solaris',remotedir='/export/home/darc')
web_srv3 = host(hostname='web_srv3',aconf='solaris.conf',arch='solaris',remotedir='/export/home/darc')
web_srv4 = host(hostname='web_srv4',aconf='solaris.conf',arch='solaris',remotedir='/export/home/darc')
sftp1 = host(hostname='sftp1',aconf='solaris.conf',arch='solaris',remotedir='/export/home/darc')

# --------------------------------------------------------------------------
# HOST LIST
# --------------------------------------------------------------------------
#
# only hosts in host_list are actually monitored
#

host_list = [subversion,web_srv1,web_srv2,web_srv3,web_srv4,sftp1]



#EOF
